//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Email for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to generate dates using a recurrence pattern
//==========================================================================================================//

import com.aspose.email.ByDay;
import com.aspose.email.DateCollection;
import com.aspose.email.Frequency;
import com.aspose.email.RecurrencePattern;
import com.aspose.email.RecurrenceRule;
import java.util.Date;

public class ICalendarGenerateDates
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        // Create new recurrence pattern
        RecurrencePattern recPattern = new RecurrencePattern();
        System.out.println("Create pattern using Aspose classes");
        // Set start date
        recPattern.setStartDate(new Date(97, 8, 2, 9, 0, 0));
        System.out.println("Start date: " + recPattern.getStartDate());
        // Add a new rule
        RecurrenceRule rule = recPattern.getRRules().add();
        rule.setFrequency(Frequency.WEEKLY); // Weekly occurrence
        rule.setUntil(new Date(97, 9, 7, 0, 0, 0)); // Repeat until this date
        rule.setWeekStart(0);
        rule.getByDay().add(new ByDay(0)); // 0: Sunday
        rule.getByDay().add(new ByDay(1)); // 1: Monday

        // Get all the dates generated by this rule
        DateCollection dateColl = recPattern.generateOccurrences();
        for (int i=0 ; i<dateColl.size() ; i++)
        {
            System.out.println(dateColl.getItem(i).toString());
        }

        // Set the same pattern using the iCalendar specifications
        System.out.println("\n\nCreate pattern using the iCalendar specifications");
        String pattern = "DTSTART:19970902T090000\n" +
            "RRULE:FREQ=WEEKLY;UNTIL=19971007T000000Z;WKST=SU;BYDAY=SU,MO";
        recPattern = null;
        recPattern = new RecurrencePattern(pattern);
        System.out.println("Start date: " + recPattern.getStartDate());

        // Get all the dates generated by this rule
        DateCollection dateColl1 = recPattern.generateOccurrences();
        for (int i=0 ; i<dateColl1.size() ; i++)
        {
            System.out.println(dateColl1.getItem(i).toString());
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.email.License licEmail = new com.aspose.email.License();
            licEmail.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
