//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Email for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to load embedded messages from an MSG file using recursive method
//==========================================================================================================//

import com.aspose.email.Attachment;
import com.aspose.email.MailMessage;
import com.aspose.email.MessageFormat;

public class LoadEmbeddedMsg
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        try
        {
            System.out.print("Reading message with embedded messages....");

            MailMessage message = MailMessage.load(strBaseFolder + "message 1.msg", MessageFormat.getMsg());
            ParseMessage(message);

            System.out.println("Success");
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void ParseMessage(MailMessage message)
    {
        System.out.println("Subject: " + message.getSubject());
        System.out.println("Extracting attachments....");
        for (int i = 0; i < message.getAttachments().size(); i++)
        {
            Attachment att = (Attachment) message.getAttachments().get(i);
            System.out.println("Attachment Name: " + att.getName());

            // Get the name of attachment. If msg subject contains characters like :, /, \ etc, replace with space
            // because windows cannot save files with these characters
            // also save first 50 characters as file name to avoid long file names
            String attFileName = att.getName().replace(".eml", "").replace(":", " ").replace("\\", " ").replace("/", " ").replace("?", "");
            if (attFileName.length() > 50)
            {
                attFileName = attFileName.substring(0, 50);
            }
            String attExt = (att.getName().substring(att.getName().lastIndexOf("."), att.getName().lastIndexOf(".") + 4));

            // Save the attachment to disk
            att.save(strBaseFolder + attFileName + attExt);

            // Check if it is an orphaned text attachment file (ATT00001.txt....) and of type eml
            if ((attExt.equals(".eml")) || (att.getContentType().getMediaType().equals("text/plain") && att.getName().contains(".txt") == true && att.getName().contains("ATT") == true))
            {
                // Try to load this text file in MailMessage
                MailMessage attMsg = MailMessage.load(strBaseFolder + attFileName + attExt, MessageFormat.getEml());
                // Call the function recursively to parse this message and attachments
                ParseMessage(attMsg);
            }
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.email.License licEmail = new com.aspose.email.License();
            licEmail.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
