//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Email for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to convert messages between EML, MSG and MHTML formats
//==========================================================================================================//

import com.aspose.email.MailMessage;
import com.aspose.email.MailMessageSaveType;
import com.aspose.email.MessageFormat;

public class MessageFormatConverter
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        try
        {
            // Convert EML to MSG and MHT
            emlConverter();

            // Convert MSG to EML and MHT
            msgConverter();

            // Convert MHT to EML and MSG
            mhtConverter();
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void mhtConverter()
    {
        try
        {
            // Set path of source (MHT) and destination (EML and MSG) files
            String strMhtFile = strBaseFolder + "New.mhtml";
            String strMsgFile = strBaseFolder + "New-out.msg";
            String strEmlFile = strBaseFolder + "New-out.eml";

            System.out.print("Loading MHT file...." + strMhtFile);
            // Load MHT file
            MailMessage message = MailMessage.load(strMhtFile, MessageFormat.getMht());
            System.out.println(" Done.");
            // Save as EML
            message.save(strEmlFile, MailMessageSaveType.getEmlFormat());
            System.out.println("Saved in EML format successfully. " + strEmlFile);
            // Save as MSG
            message.save(strMsgFile, MailMessageSaveType.getOutlookMessageFormatUnicode());
            System.out.println("Saved in MSG format successfully. " + strMsgFile);
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void msgConverter()
    {
        try
        {
            // Set path of source (MSG) and destination (EML and MHT) files
            String strMsgFile = strBaseFolder + "New.msg";
            String strEmlFile = strBaseFolder + "New-out.eml";
            String strMhtFile = strBaseFolder + "New-out.mhtml";

            System.out.print("Loading MSG file...." + strMsgFile);
            // Load MSG file
            MailMessage message = MailMessage.load(strMsgFile, MessageFormat.getMsg());
            System.out.println(" Done.");
            // Save as EML
            message.save(strEmlFile, MailMessageSaveType.getEmlFormat());
            System.out.println("Saved in EML format successfully. " + strEmlFile);
            // Save as MHT
            message.save(strMhtFile, MailMessageSaveType.getMHtmlFromat());
            System.out.println("Saved in MHTML format successfully. " + strMhtFile);
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void emlConverter()
    {
        try
        {
            // Set path of source (EML) and destination (MSG and MHT) files
            String strEmlFile = strBaseFolder + "New.eml";
            String strMsgFile = strBaseFolder + "New-out.msg";
            String strMhtFile = strBaseFolder + "New-out.mhtml";

            System.out.print("Loading EML file...." + strEmlFile);
            // Load EML file
            MailMessage message = MailMessage.load(strEmlFile, MessageFormat.getEml());
            System.out.println(" Done.");
            // Save as MSG
            message.save(strMsgFile, MailMessageSaveType.getOutlookMessageFormatUnicode());
            System.out.println("Saved in MSG format successfully. " + strMsgFile);
            // Save as MHT
            message.save(strMhtFile, MailMessageSaveType.getMHtmlFromat());
            System.out.println("Saved in MHTML format successfully. " + strMhtFile);
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.email.License licEmail = new com.aspose.email.License();
            licEmail.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
