//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Email for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to load an MSG file and convert it to
// various formats (PDF, Doc, XPS) with the help of Aspose.Words for Java
//==========================================================================================================//

import com.aspose.email.MailMessage;
import com.aspose.email.MailMessageSaveType;
import com.aspose.email.MessageFormat;
import com.aspose.words.Document;
import com.aspose.words.SaveFormat;

public class MsgToOtherFormats
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        // Set the file names and paths for source (MSG) and destination (Doc, Pdf, XPS) files
        String strMSGFile = strBaseFolder + "New.msg";
        String strMHTFile = strBaseFolder + "New-out.mhtml";
        String strDocFile = strBaseFolder + "New-out.doc";
        String strPdfFile = strBaseFolder + "New-out.pdf";
        String strXPSFile = strBaseFolder + "New-out.xps";

        try
        {
            System.out.println("Loading MSG file....");
            // Load message in MSG format
            MailMessage message = MailMessage.load(strMSGFile, MessageFormat.getMsg());

            System.out.println("Saving message in MHTML format....");
            // Save the message in MHTML format
            message.save(strMHTFile, MailMessageSaveType.getMHtmlFromat());

            System.out.println("Loading MHTML file in Aspose.Words for Java....");
            // Load the MHTML file in Aspose.Words for Java
            Document document = new Document(strMHTFile);

            System.out.println("Saving the document in Doc, Pdf and Xps formats....");
            // Save in different supported formats
            document.save(strDocFile, SaveFormat.DOC);
            document.save(strPdfFile, SaveFormat.PDF);
            document.save(strXPSFile, SaveFormat.XPS);
            System.out.println("Documents saved successfully.");
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.email.License licEmail = new com.aspose.email.License();
            licEmail.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");

            com.aspose.words.License licWords = new com.aspose.words.License();
            licWords.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
