//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Email for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to load an Outlook PST file and extract all Contacts from
// PST and save the contacts in VCard format to disk.
//==========================================================================================================//

import com.aspose.email.ContactSaveFormat;
import com.aspose.email.FolderInfo;
import com.aspose.email.MapiContact;
import com.aspose.email.MapiMessage;
import com.aspose.email.MessageInfo;
import com.aspose.email.MessageInfoCollection;
import com.aspose.email.PersonalStorage;
import java.io.File;

public class PSTExtractContacts
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        String pstFileName = strBaseFolder + "Outlook.pst";

        try
        {
            // load the Outlook PST file
            PersonalStorage pst = PersonalStorage.fromFile(pstFileName);

            // get the Contacts folder
            FolderInfo folderInfo = pst.getRootFolder().getSubFolder("Contacts");
            new File(strBaseFolder + "Contacts").mkdir();

            // loop through all the contacts in this folder
            MessageInfoCollection messageInfoCollection = folderInfo.getContents();
            for (int i = 0; i < messageInfoCollection.size(); i++)
            {
                // Get contact information in MapiContact instance
                MessageInfo messageInfo = (MessageInfo)messageInfoCollection.get(i);
                MapiContact contact = (MapiContact)pst.extractMessage(messageInfo).toMapiMessageItem();

                // Display contact information on screen
                System.out.println("Name: " + contact.getNameInfo().getDisplayName());
                System.out.println("Company Name: " + contact.getProfessionalInfo().getCompanyName());

                // save the contact to disk in VCF format
                contact.save(strBaseFolder + "Contacts\\" + contact.getNameInfo().getDisplayName() + ".vcf", ContactSaveFormat.V_CARD);
            }
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.email.License licEmail = new com.aspose.email.License();
            licEmail.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
